@@ -215,18 +215,6 @@ def test_ecdf_percentile():
     np.testing.assert_almost_equal(ecdf_percentile(noiseWave), (-0.8095410722491809, 0.796916231269631))
 
 
-def test_ecdf_slope():
-    np.testing.assert_almost_equal(ecdf_slope(const0), np.inf)
-    np.testing.assert_almost_equal(ecdf_slope(const1), np.inf)
-    np.testing.assert_almost_equal(ecdf_slope(constNeg), np.inf)
-    np.testing.assert_almost_equal(ecdf_slope(constF), np.inf)
-    np.testing.assert_almost_equal(ecdf_slope(lin), 0.05)
-    np.testing.assert_almost_equal(ecdf_slope(lin0), 0.0475)
-    np.testing.assert_almost_equal(ecdf_slope(wave), 0.3535534)
-    np.testing.assert_almost_equal(ecdf_slope(offsetWave), 0.3535534)
-    np.testing.assert_almost_equal(ecdf_slope(noiseWave), 0.3594095)
-
-
 def test_ecdf_percentile_count():
     np.testing.assert_almost_equal(ecdf_percentile_count(const0), (0, 0))
     np.testing.assert_almost_equal(ecdf_percentile_count(const1), (1, 1))
@@ -753,25 +741,47 @@ def test_fft_mean_coeff():
 
 
 def test_lpcc():
-    np.testing.assert_almost_equal(lpcc(const0), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
-    np.testing.assert_almost_equal(lpcc(const1), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
-    np.testing.assert_almost_equal(lpcc(constNeg), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
-    np.testing.assert_almost_equal(lpcc(constF), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
-    np.testing.assert_almost_equal(lpcc(lin), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
-    np.testing.assert_almost_equal(lpcc(lin0), (0.017793342850434657, 0.12419699587050197, 0.17985773867565555,
-                                                0.13749027713829948, 0.14521059821841656, 0.14362411136332903,
-                                                0.14403924127165643, 0.14362411136332903, 0.14521059821841656,
-                                                0.13749027713829948, 0.17985773867565555, 0.12419699587050197))
-    np.testing.assert_almost_equal(lpcc(wave), (8.08705689884851e-07, 0.10193422882411193, 0.0051922525746904875,
-                                                0.0003496693593067946, 2.355214618130234e-05, 1.2419899263690914e-06,
-                                                3.091008802744081e-06, 1.2419899263690914e-06, 2.355214618130234e-05,
-                                                0.0003496693593067946, 0.0051922525746904875, 0.10193422882411193))
-    np.testing.assert_almost_equal(lpcc(offsetWave), (8.087054868870942e-07, 0.10193422882503231, 0.005192252575236202,
-                                                      0.0003496693583308415, 2.3552147454092374e-05,
-                                                      1.241991615337501e-06, 3.0910069449505212e-06,
-                                                      1.241991615337501e-06, 2.3552147454092374e-05,
-                                                      0.0003496693583308415, 0.005192252575236202, 0.10193422882503231))
-    np.testing.assert_almost_equal(lpcc(noiseWave), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
+    np.testing.assert_almost_equal(lpcc(const0), (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
+    np.testing.assert_almost_equal(lpcc(const1), ((0.020164333842602966, 0.9865688990210231, 0.5256081668917854,
+                                                   0.36558947821279086, 0.2920451699576349, 0.25507545331173936,
+                                                   0.23917931511018226, 0.23917931511018226, 0.25507545331173936,
+                                                   0.2920451699576349, 0.36558947821279086, 0.5256081668917854,
+                                                   0.9865688990210231)))
+    np.testing.assert_almost_equal(lpcc(constNeg), (0.020164333842602966, 0.9865688990210231, 0.5256081668917854,
+                                                    0.36558947821279086, 0.2920451699576349, 0.25507545331173936,
+                                                    0.23917931511018226, 0.23917931511018226, 0.25507545331173936,
+                                                    0.2920451699576349, 0.36558947821279086, 0.5256081668917854,
+                                                    0.9865688990210231))
+    np.testing.assert_almost_equal(lpcc(constF), (0.020164333842599635, 0.9865688990210177, 0.5256081668917822,
+                                                  0.365589478212793, 0.29204516995764224, 0.2550754533117383,
+                                                  0.2391793151101857, 0.2391793151101857, 0.2550754533117383,
+                                                  0.29204516995764224, 0.365589478212793, 0.5256081668917822,
+                                                  0.9865688990210177))
+    np.testing.assert_almost_equal(lpcc(lin), (0.009787922299081098, 0.9403087900526141, 0.45515839811652303,
+                                               0.2959902388191573, 0.2226794080995073, 0.18587538078947108,
+                                               0.17006234165994988, 0.17006234165994988, 0.18587538078947108,
+                                               0.2226794080995073, 0.2959902388191573, 0.45515839811652303,
+                                               0.9403087900526141))
+    np.testing.assert_almost_equal(lpcc(lin0), (0.14693248468111308, 0.7098379679548503, 0.27136979375401815,
+                                                0.12066884688694682, 0.054365468824491156, 0.022184966988290034,
+                                                0.00867554638640014, 0.00867554638640014, 0.022184966988290034,
+                                                0.054365468824491156, 0.12066884688694682, 0.27136979375401815,
+                                                0.7098379679548503))
+    np.testing.assert_almost_equal(lpcc(wave), (0.27326478573784635, 2.2503511377184005, 1.3120406566259146,
+                                                0.9508372630850437, 0.8377303045711273, 0.7195725472552679,
+                                                0.715238952271539, 0.715238952271539, 0.7195725472552679,
+                                                0.8377303045711273, 0.9508372630850437, 1.3120406566259146,
+                                                2.2503511377184005))
+    np.testing.assert_almost_equal(lpcc(offsetWave), (0.5435105244008235, 1.5815770053561224, 1.1189968861619681,
+                                                      0.9577304362743059, 0.8832739401503552, 0.8458651104475441,
+                                                      0.8295606293469393, 0.8295606293469393, 0.8458651104475441,
+                                                      0.8832739401503552, 0.9577304362743059, 1.1189968861619681,
+                                                      1.5815770053561224))
+    np.testing.assert_almost_equal(lpcc(noiseWave), (0.332943861278751, 0.535742501182159, 0.6994290294792235,
+                                                     0.699314211544821, 0.6700910097813829, 0.67785538535114,
+                                                     0.7162476787322745, 0.7162476787322745, 0.67785538535114,
+                                                     0.6700910097813829, 0.699314211544821, 0.6994290294792235,
+                                                     0.535742501182159))
 
 
 def test_spectral_entropy():
